@@ -29,6 +29,27 @@ typedef enum
 	GLADE_SUPPORT_LIBGLADE_ONLY        = (0x01 << 3)
 } GladeSupportMask;
 
+/**
+ * GladeProjectModelColumns:
+ * @GLADE_PROJECT_MODEL_ICON_NAME: name of the icon for the widget
+ * @GLADE_PROJECT_MODEL_ICON_NAME_COLUMN_NAME: Name of the widget
+ * @GLADE_PROJECT_MODEL_ICON_NAME_COLUMN_OBJECT: the GObject of the widget
+ * @GLADE_PROJECT_MODEL_ICON_NAME_N_COLUMNS: Number of columns
+ *
+ * The tree view columns provided by the GtkTreeModel implemented
+ * by GladeProject
+ *
+ **/
+typedef enum
+{
+	GLADE_PROJECT_MODEL_COLUMN_ICON_NAME,
+	GLADE_PROJECT_MODEL_COLUMN_NAME,
+	GLADE_PROJECT_MODEL_COLUMN_TYPE_NAME,
+	GLADE_PROJECT_MODEL_COLUMN_OBJECT,
+	GLADE_PROJECT_MODEL_COLUMN_MISC,
+	GLADE_PROJECT_MODEL_N_COLUMNS
+} GladeProjectModelColumns;
+
 struct _GladeProject
 {
 	GObject parent_instance;
@@ -74,8 +95,10 @@ GladeProject  *glade_project_load                (const gchar  *path);
 gboolean       glade_project_save                (GladeProject *project, 
 						  const gchar   *path, 
 						  GError       **error);
-						 
-const gchar   *glade_project_get_path            (GladeProject *project);						 
+
+void           glade_project_preview             (GladeProject *project, GladeWidget *gwidget);
+
+const gchar   *glade_project_get_path            (GladeProject *project);
 
 gchar         *glade_project_get_name            (GladeProject *project);
 
@@ -158,13 +181,11 @@ gchar         *glade_project_resource_fullpath    (GladeProject  *project,
 gboolean       glade_project_is_loading           (GladeProject *project);
  
 time_t         glade_project_get_file_mtime       (GladeProject *project);
-  
-guint          glade_project_get_instance_count   (GladeProject *project);
-
-void           glade_project_set_instance_count   (GladeProject *project, guint instance_count);
 
 gboolean       glade_project_get_modified         (GladeProject *project);
 
+gboolean       glade_project_get_previewable      (GladeProject *project);
+
 void           glade_project_set_format      	  (GladeProject *project, GladeProjectFormat format);
 
 GladeProjectFormat glade_project_get_format  	  (GladeProject *project);
@@ -182,10 +203,19 @@ void          glade_project_verify_project_for_ui (GladeProject  *project);
 GList        *glade_project_required_libs          (GladeProject       *project);
 
 void          glade_project_set_naming_policy      (GladeProject       *project,
-						    GladeNamingPolicy   policy,
-						    gboolean            use_command);
+						    GladeNamingPolicy   policy);
 
 GladeNamingPolicy glade_project_get_naming_policy  (GladeProject       *project);
+void          glade_project_get_target_version     (GladeProject       *project,
+						    const gchar        *catalog,
+						    gint               *major,
+						    gint               *minor);
+
+void          glade_project_update_signal_support_warning (GladeWidget  *widget,
+							   GladeSignal  *signal);
+
+
+gchar        *glade_project_display_dependencies (GladeProject *project);
 
 G_END_DECLS
 
