@@ -161,6 +161,22 @@ gint              glade_utils_hijack_key_press (GtkWindow          *win,
 
 gchar           *glade_utils_replace_home_dir_with_tilde (const gchar *uri);
 
+void             glade_utils_cairo_draw_line (cairo_t  *cr,
+					      GdkColor *color,
+					      gint      x1,
+					      gint      y1,
+					      gint      x2,
+					      gint      y2);
+
+
+void             glade_utils_cairo_draw_rectangle (cairo_t *cr,
+						   GdkColor *color,
+						   gboolean filled,
+						   gint x,
+						   gint y,
+						   gint width,
+						   gint height);
+
 G_END_DECLS
 
 #endif /* __GLADE_UTILS_H__ */
